#
# spec file for package libpgf
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_ver 7
Name:           libpgf
Version:        7.21.7
Release:        1.13
Summary:        Progressive Graphics File Library
License:        LGPL-2.1-or-later
Group:          Productivity/Graphics/Other
URL:            https://www.libpgf.org/
Source0:        https://sourceforge.net/projects/%{name}/files/%{name}/%{version}/libpgf.zip
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  unzip

%description
libpgf is a library for working with PGF (Progresive Graphics File) images.

%package devel
Summary:        Development files for the libpgf library
Group:          Development/Libraries/C and C++
Requires:       libpgf%{so_ver} = %{version}

%description devel
This package contains header files and libraries needed for developing programs
using the libpgf library.

%package -n libpgf%{so_ver}
Summary:        Progressive Graphics File Library
Group:          System/Libraries

%description -n libpgf%{so_ver}
libpgf is a library for working with PGF (Progresive Graphics File) images.

%prep
%setup -q -n %{name}

# Fix autogen.sh failure "wrong-file-end-of-line-encoding"
find . -name Makefile.am | xargs sed -i 's/\r$//'
sed -i 's/\r$//' config.h.in
sed -i 's/\r$//' configure.ac
sed -i 's/\r$//' autogen.sh

# Fix autogen.sh failure
touch README

# Add "libpgf-" prefix to all man pages to prevent conflicts with other packages
sed -i 's/\$(mandir)\/man3\/\$\$f/\$(mandir)\/man3\/libpgf-\$\$f/' doc/Makefile.am

# Fix rpmlint warning "wrong-file-end-of-line-encoding"
sed -i 's/\r$//' README.txt

# Remove build time references so build-compare can do its work
echo "HTML_TIMESTAMP = NO" >> doc/Doxyfile.in

%build
sh autogen.sh
%configure --disable-static
%make_build

%install
%make_install DOC_DIR=%{buildroot}%{_docdir}/%{name}-devel/

# Remove libtool config files
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libpgf%{so_ver} -p /sbin/ldconfig
%postun -n libpgf%{so_ver} -p /sbin/ldconfig

%files devel
%license COPYING
%doc README.txt
%doc %{_docdir}/%{name}-devel/
%{_includedir}/libpgf/
%{_libdir}/pkgconfig/libpgf.pc
%{_libdir}/libpgf.so
%{_mandir}/man3/libpgf-*.3%{?ext_man}

%files -n libpgf%{so_ver}
%{_libdir}/libpgf.so.%{so_ver}*

%changelog
* Sat Feb 27 2021 Asterios Dramis <asterios.dramis@gmail.com>
- Update to version 7.21.7:
  * This bug fix is for ROI decoding only. This bug fix is
    necessary if several Read() and ResetStreamPos() operations are
    called with the same PGFimage object after a single Open()
    call.
  From version 7.21.2:
  * Documentation and build tool update.
* Sat Apr 20 2019 Asterios Dramis <asterios.dramis@gmail.com>
- Update to version 7.19.3:
  * This version fixes a compilation bug seen when ROI support is
    disabled.
* Thu Feb 15 2018 asterios.dramis@gmail.com
- Update to version 7.15.32:
  * This version improves the reuse of CPGFImage objects for
    several decoding operations. It clarifies the usage of
    CPGFImage::Close() and CPGFImage::Destroy() by deletion of
    Close(). Several reading operations can be performed in the
    following way: Open(), Read(), GetBitmap(), ResetStreamPos(),
    Read(), GetBitmap(), ResetStreamPos(), ... Calling Destroy()
    frees all allocated ressources and reinitializes the object to
    the same state as the constructor does. This allows the reuse
    of the CPGFImage object for encoding and decoding: SetHeader(),
    ImportBitmap(), Write(), ResetStreamPos(), Destroy(), Open(),
    Read(), GetBitmap()
  * Caching or skipping of user data (meta data) while opening a
    PGF image can be controlled by a new UserdataPolicy in
    ConfigureDecoder().
  From version 7.15.25:
  * In case you use the ROI decoding, we strongly encourage using
    version 7.15.25 instead of an older version.
  * This version fixes some decoder bugs only seen in ROI decoding.
    ROI decoding is now also supported for Bitmap and RGB12 image
    modes.
  * This version introduces a new and more efficient data format
    for binary images (bitmaps). The new format allows ROI
    decoding. The decoder supports both the old and the new format,
    but ROI decoding works only with the new format.
  * The two reserverd bytes in PGFHeader are now used for a more
    detailled PGF version number.
- Removed libpgf-r147.patch and libpgf-r148.patch (fixed upstream).
* Mon Sep  7 2015 asterios.dramis@gmail.com
- Added the following security patches from upstream:
  * libpgf-r147.patch, libpgf-r148.patch
    Fix use-after-free vulnerability in Decoder.cpp
    CVE-2015-6673, bnc#943304, boo#941059
* Fri Aug  8 2014 asterios.dramis@gmail.com
- Update to version 6.14.12:
  * The new version is a minor update of version 6.12.24.
  * It mainly contains some fixes of memory leaks in the OpenMP part and some
    improvements suggested by cppcheck and Coverity.
* Thu Feb 13 2014 asterios.dramis@gmail.com
- Update to version 6.13.45.svn123:
  * Detailed changelog not available.
  * Fix memory leak in digikam (kde#326525, bnc#854323).
- Removed automake-1.13.patch (fixed upstream).
* Sat Mar 23 2013 asterios.dramis@gmail.com
- Added a patch "automake-1.13.patch" to fix build with automake 1.13.
- Fix build in SLE 11 SP2 and openSUSE 11.4.
* Sun Oct 28 2012 asterios.dramis@gmail.com
- Initial release (version 6.12.24).
